package jfftw.demo;
import jfftw.*;

/**     Simple test program for two dimensional Complex FFts. 
 *      Program forms 2-D complex DataArray filled with Randoms
 *      take two centered FFT and compared to reference copy of original.
 *
 *      In you run this with VERY large arrays you will run out of 
 *      default heap memory. If this happens (on Linux) use the
 *      -Xmx<nnn>M flag, so 
 *      <p>
 *      java -Xmx512M TwoDimensionalDemo 4096 4096
 *      <p>
 *      will (eventually!!!) take a 4096x4096 complex FFT, provided
 *      your system has enough physical memory that it does not 
 *      swap-thrash its self into the ground!!! 
 * 
 *      @author Will Hossack, The University of Edinburgh
 */

public class TwoDimensionDemo {
    public static void main(String args[]) {

	if (args.length < 2) {
	    System.out.println("Usage: java TwoDimensionTest w h");
	    System.exit(1);
	}

	//          Get width and height from command line.
	int width = Integer.parseInt(args[0]);
	int height = Integer.parseInt(args[1]);

	//        Make the complex data array of the correct size.
	ComplexDataArray im = new ComplexDataArray(width,height);

	//        Fill real parts with randoms, imaginary defaults to zero.
	for(int j = 0; j < im.getHeight(); j++) {
	    for(int i = 0; i < im.getWidth(); i++) {
		im.setDouble(i,j,Math.random());
	    }
	}

	System.out.println(im);             // Information.

	//            Take copy in RealDataArray, taking real part only
	//            
	RealDataArray ref = im.getRealDataArray(Complex.REAL);
	System.out.println(ref);             // Information.

	//            Take centred FFT
	//            If sizes not even, you will get an warning message
	//            and standard FFT will be taken (but it still works)
	im.centreFourier();
	System.out.println(im);             // Information.

	//            Take second centred FFT

	im.centreFourier();
	System.out.println(im);             // Information.

	//           Take difference between im and ref using getDouble()
	//           access scheme.
	double diff = 0.0;
	im.setConversion(Complex.REAL);        // Set getDouble conversion
                                               // to get real value.
	
	//           Form modulus difference between double FFT(ed) and ref.
	//           using two-dimensional access.
	for(int j = 0; j < im.getHeight(); j++) {
	    for(int i = 0; i < im.getWidth(); i++) {
		diff += Math.abs(im.getDouble(i,j) - ref.getDouble(i,j));
	    }
	}
	//          Print of difference (should be small !!!)
	System.out.println("Difference is : " + diff);
				 
	
    }
}